@@ -46,7 +46,7 @@ class LoLAPI:
         if headers is None:
             headers = {}
         async with request(method, url, headers = headers) as response:
-            print(response.status, url)
+            # print(response.status, url)
             return await response.json() if response.status == 200 else {}
     
     async def __make_api_request(self, url: str) -> Any:
