@@ -179,13 +179,15 @@ class MetadataDto(AsyncRiotApiResponse):
 class InfoDto(AsyncRiotApiResponse):
     def __init__(self, gameCreation: int, gameDuration: int, gameId: int, gameMode: str, gameName: str,
                  gameStartTimestamp: int, gameType: str, gameVersion: str, mapId: int, participants: List[str],
-                 platformId: str, queueId: int, teams: List[dict], tournamentCode: str, **kwargs):
+                 platformId: str, queueId: int, teams: List[dict], tournamentCode: str,
+                 gameEndTimestamp: int = 0):
         self.gameCreation = gameCreation
         self.gameDuration = gameDuration
         self.gameId = gameId
         self.gameMode = gameMode
         self.gameName = gameName
         self.gameStartTimestamp = gameStartTimestamp
+        self.gameEndTimestamp = gameEndTimestamp or gameStartTimestamp + gameDuration
         self.gameType = gameType
         self.gameVersion = gameVersion
         self.mapId = mapId
@@ -194,6 +196,7 @@ class InfoDto(AsyncRiotApiResponse):
         self.queueId = queueId
         self.teams: List[TeamDto] = list(map(lambda x: TeamDto(**x), teams))
         self.tournamentCode = tournamentCode
+        self.gameDurationSeconds: int = gameDuration > 10000 and gameDuration // 1000 or gameDuration
 
 
 class ParticipantDto(AsyncRiotApiResponse):
